@@ -1,8 +1,4 @@
 from dofast.simple_parser import SimpleParser
-from dofast.oss import Bucket, Message
-import dofast.utils as du
-
-from .toolkits.telegram import read_hema_bot, download_file_by_id, bot_messalert
 from .network import Network, PapaPhone
 from .linuxtools import LinuxTools
 
@@ -14,6 +10,7 @@ msg = """VPS toolkits 😏
 -socks [port] ::: Set up a socks5 proxy.
 
 -flow(--dataflow)::: papa cellphone dataflow monitor.
+-hx(--happyxiao) ::: HappyXiao briefing newsletter.
 """
 
 
@@ -24,6 +21,7 @@ def parse_arguments():
     sp.add_argument('-p', '--phone')
     sp.add_argument('-socks', '--socks')
     sp.add_argument('-flow', '--dataflow')
+    sp.add_argument('-hx', '--happyxiao')
     sp.parse_args()
 
     if sp.monitor:
@@ -44,6 +42,10 @@ def parse_arguments():
         from .crontab import papa_phone_dataflow
         papa_phone_dataflow()
 
+    elif sp.happyxiao:
+        from .crontab import HappyXiao
+        HappyXiao.rss()
+
     else:
         for l in msg.split("\n"):
             c, e = (l + " ::: ").split(':::')[:2]
